@@ -1,5 +1,6 @@
 /*************************************************************************
  *  Copyright (C) 2008, 2009, 2010, 2012 by Volker Lanz <vl@fidra.de>    *
+ *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -989,10 +990,10 @@ static KLocalizedString checkSupportInNode(const PartitionNode* parent)
             continue;
 
         if (node->children().size() > 0)
-            rval = kxi18n("%1 %2").subs(rval).subs(checkSupportInNode(node));
+            rval = kxi18n("%1%2").subs(rval).subs(checkSupportInNode(node));
 
         if (!p->fileSystem().supportToolFound() && !p->fileSystem().supportToolName().name.isEmpty())
-            rval = kxi18n("%1 %2").subs(rval).subs(kxi18n("<tr>"
+            rval = kxi18n("%1%2").subs(rval).subs(kxi18n("<tr>"
                                    "<td>%1</td>"
                                    "<td>%2</td>"
                                    "<td>%3</td>"
@@ -1014,9 +1015,9 @@ void MainWindow::checkFileSystemSupport()
 
     foreach(const Device * d, operationStack().previewDevices()) {
         supportInNode = checkSupportInNode(d->partitionTable());
-        if (!supportInNode.isEmpty()) {
+        if (supportInNode.toString() != QStringLiteral()) {
             missingSupportTools = true;
-            supportList = kxi18n("%1 %2").subs(supportList).subs(supportInNode);
+            supportList = kxi18n("%1%2").subs(supportList).subs(supportInNode);
         }
     }
 
