@@ -19,10 +19,8 @@
 
 #define PARTITIONMANAGERWIDGET__H
 
-#include <kpmcore/core/operationstack.h>
-#include <kpmcore/core/operationrunner.h>
-
-#include "util/libpartitionmanagerguiexport.h"
+#include <core/operationstack.h>
+#include <core/operationrunner.h>
 
 #include "ui_partitionmanagerwidgetbase.h"
 
@@ -40,7 +38,7 @@ class QPoint;
 
     @author Volker Lanz <vl@fidra.de>
 */
-class LIBKPMGUI_EXPORT PartitionManagerWidget : public QWidget, Ui::PartitionManagerWidgetBase
+class PartitionManagerWidget : public QWidget, Ui::PartitionManagerWidgetBase
 {
     Q_OBJECT
     Q_DISABLE_COPY(PartitionManagerWidget)
